==> pkg-js-tools_0.8.10.tar.xz: pkg-js-tools-0.8.10/lintian/checks/pkg-js/testsuite.pm <==
# pkg-js/no-testsuite -- lintian check script for detecting a missing Testsuite header -*- js -*-
#
# Copyright © 2013 Niels Thykier <niels@thykier.net>
# Copyright © 2013 gregor herrmann <gregoa@debian.org>
# Copyright © 2014 Niko Tyni <ntyni@debian.org>
# Copyright © 2018 Florian Schlichting <fsfs@debian.org>
# Copyright © 2019 Xavier Guimard <yadd@debian.org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, you can find it on the World Wide
# Web at http://www.gnu.org/copyleft/gpl.html, or write to the Free
# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
# MA 02110-1301, USA.

package Lintian::pkg_js::testsuite;

use strict;
use warnings;

use Lintian::Tags qw(tag);

sub run {
    my ( $pkg, $type, $info, $proc, $group ) = @_;

    # Only for pkg-js packages
    return
      unless $info->field('maintainer') =~
      /pkg-javascript-maintainers\@lists\.alioth\.debian\.org/sm;

    # Only for source packages
    return unless $type eq 'source';

    if ( !defined $info->field('testsuite') ) {
        tag 'missing-testsuite-header';
        return;
    }

    if ( $info->field('testsuite') ne 'autopkgtest-pkg-nodejs' ) {
        tag 'nonteam-testsuite-header', $info->field('testsuite');
        return;
    }
    return;
}

1;

==> pkg-js-tools_0.9.16.tar.xz: pkg-js-tools-0.9.16/lintian/checks/pkg-js/testsuite.pm <==
# pkg-js/no-testsuite -- lintian check script for detecting a missing Testsuite header -*- js -*-
#
# Copyright © 2013 Niels Thykier <niels@thykier.net>
# Copyright © 2013 gregor herrmann <gregoa@debian.org>
# Copyright © 2014 Niko Tyni <ntyni@debian.org>
# Copyright © 2018 Florian Schlichting <fsfs@debian.org>
# Copyright © 2019 Xavier Guimard <yadd@debian.org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, you can find it on the World Wide
# Web at http://www.gnu.org/copyleft/gpl.html, or write to the Free
# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
# MA 02110-1301, USA.

package Lintian::pkg_js::testsuite;

use strict;
use warnings;

use Lintian::Tags qw(tag);

sub run {
    my ( $pkg, $type, $info, $proc, $group ) = @_;

    # Only for pkg-js packages
    return
      unless $info->field('maintainer') =~
      /pkg-javascript-maintainers\@lists\.alioth\.debian\.org/sm;

    # Only for source packages
    return unless $type eq 'source';

    if ( !defined $info->field('testsuite') ) {
        tag 'missing-pkg-js-testsuite-header';
        return;
    }

    if ( $info->field('testsuite') ne 'autopkgtest-pkg-nodejs' ) {
        tag 'non-js-team-testsuite-header', $info->field('testsuite');
        return;
    }
    return;
}

1;
